@@ -29,14 +29,14 @@
 
 
 #include <cmath>
-#include <cstdlib>
 #include <cstring>
-#include <fstream>
-#include <iostream>
+#include <iostream>  // IWYU pragma: keep  // BUG WORK-AROUND
 #include <map>
 #include <sstream>
+#include <string>
 
 #include "KIM_ModelDriverHeaders.hpp"
+#include "LennardJones612.hpp"
 #include "LennardJones612Implementation.hpp"
 
 #define MAXLINE 1024
@@ -299,16 +299,19 @@ int LennardJones612Implementation::OpenParameterFiles(
     return ier;
   }
 
+  std::string const * paramFileDirName;
+  modelDriverCreate->GetParameterFileDirectoryName(&paramFileDirName);
   for (int i = 0; i < numberParameterFiles; ++i)
   {
     std::string const * paramFileName;
-    ier = modelDriverCreate->GetParameterFileName(i, &paramFileName);
+    ier = modelDriverCreate->GetParameterFileBasename(i, &paramFileName);
     if (ier)
     {
       LOG_ERROR("Unable to get parameter file name");
       return ier;
     }
-    parameterFilePointers[i] = fopen(paramFileName->c_str(), "r");
+    std::string filename = *paramFileDirName + "/" + *paramFileName;
+    parameterFilePointers[i] = fopen(filename.c_str(), "r");
     if (parameterFilePointers[i] == 0)
     {
       char message[MAXLINE];
@@ -438,7 +441,9 @@ int LennardJones612Implementation::ProcessParameterFiles(
     }
 
     if (iIndex >= jIndex)
-    { indx = jIndex * N + iIndex - (jIndex * jIndex + jIndex) / 2; }
+    {
+      indx = jIndex * N + iIndex - (jIndex * jIndex + jIndex) / 2;
+    }
     else
     {
       indx = iIndex * N + jIndex - (iIndex * iIndex + iIndex) / 2;
@@ -497,8 +502,7 @@ void LennardJones612Implementation::getNextDataLine(FILE * const filePtr,
                                                     int const maxSize,
                                                     int * endOfFileFlag)
 {
-  do
-  {
+  do {
     if (fgets(nextLinePtr, maxSize, filePtr) == NULL)
     {
       *endOfFileFlag = 1;
@@ -506,7 +510,9 @@ void LennardJones612Implementation::getNextDataLine(FILE * const filePtr,
     }
     while ((nextLinePtr[0] == ' ' || nextLinePtr[0] == '\t')
            || (nextLinePtr[0] == '\n' || nextLinePtr[0] == '\r'))
-    { nextLinePtr = (nextLinePtr + 1); }
+    {
+      nextLinePtr = (nextLinePtr + 1);
+    }
   } while ((strncmp("#", nextLinePtr, 1) == 0) || (strlen(nextLinePtr) == 0));
 }
 
@@ -842,7 +848,9 @@ int LennardJones612Implementation::SetRefreshMutableValues(
       int indexJ = modelSpeciesCodeList_[j];
 
       if (influenceDistance_ < cutoffsSq2D_[indexI][indexJ])
-      { influenceDistance_ = cutoffsSq2D_[indexI][indexJ]; }
+      {
+        influenceDistance_ = cutoffsSq2D_[indexI][indexJ];
+      }
     }
   }
 
@@ -1098,7 +1106,9 @@ void AllocateAndInitialize2DArray(double **& arrayPtr,
   arrayPtr = new double *[extentZero];
   arrayPtr[0] = new double[extentZero * extentOne];
   for (int i = 1; i < extentZero; ++i)
-  { arrayPtr[i] = arrayPtr[i - 1] + extentOne; }
+  {
+    arrayPtr[i] = arrayPtr[i - 1] + extentOne;
+  }
 
   // initialize
   for (int i = 0; i < extentZero; ++i)
