@@ -19,7 +19,7 @@
 !
 
 !
-! Copyright (c) 2016--2019, Regents of the University of Minnesota.
+! Copyright (c) 2016--2020, Regents of the University of Minnesota.
 ! All rights reserved.
 !
 ! Contributors:
@@ -30,7 +30,6 @@
 ! Release: This file is part of the kim-api.git repository.
 !
 
-
 !> \brief \copybrief KIM::ModelCreate
 !!
 !! \sa KIM::ModelCreate, KIM_ModelCreate
@@ -44,13 +43,11 @@ module kim_model_create_module
   public &
     ! Derived types
     kim_model_create_handle_type, &
-
     ! Constants
     KIM_MODEL_CREATE_NULL_HANDLE, &
-
     ! Routines
-    operator (.eq.), &
-    operator (.ne.), &
+    operator(.eq.), &
+    operator(.ne.), &
     kim_set_model_numbering, &
     kim_set_influence_distance_pointer, &
     kim_set_neighbor_list_pointers, &
@@ -63,7 +60,6 @@ module kim_model_create_module
     kim_log_entry, &
     kim_to_string
 
-
   !> \brief \copybrief KIM::ModelCreate
   !!
   !! \sa KIM::ModelCreate, KIM_ModelCreate
@@ -82,16 +78,16 @@ module kim_model_create_module
   !> \brief Compares kim_model_create_handle_type's for equality.
   !!
   !! \since 2.0
-  interface operator (.eq.)
+  interface operator(.eq.)
     module procedure kim_model_create_handle_equal
-  end interface operator (.eq.)
+  end interface operator(.eq.)
 
   !> \brief Compares kim_model_create_handle_type's for inequality.
   !!
   !! \since 2.0
-  interface operator (.ne.)
+  interface operator(.ne.)
     module procedure kim_model_create_handle_not_equal
-  end interface operator (.ne.)
+  end interface operator(.ne.)
 
   !> \brief \copybrief KIM::ModelCreate::SetModelNumbering
   !!
@@ -222,7 +218,7 @@ contains
     type(kim_model_create_handle_type), intent(in) :: lhs
     type(kim_model_create_handle_type), intent(in) :: rhs
 
-    kim_model_create_handle_not_equal = .not. (lhs .eq. rhs)
+    kim_model_create_handle_not_equal = .not. (lhs == rhs)
   end function kim_model_create_handle_not_equal
 
   !> \brief \copybrief KIM::ModelCreate::SetModelNumbering
@@ -232,15 +228,16 @@ contains
   !! \since 2.0
   recursive subroutine kim_model_create_set_model_numbering( &
     model_create_handle, numbering, ierr)
-    use kim_numbering_module, only : kim_numbering_type
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_numbering_module, only: kim_numbering_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
-      integer(c_int) recursive function set_model_numbering(model_create, &
-        numbering) bind(c, name="KIM_ModelCreate_SetModelNumbering")
+      integer(c_int) recursive function set_model_numbering( &
+        model_create, numbering) &
+        bind(c, name="KIM_ModelCreate_SetModelNumbering")
         use, intrinsic :: iso_c_binding
-        use kim_numbering_module, only : kim_numbering_type
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_numbering_module, only: kim_numbering_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(kim_numbering_type), intent(in), value :: numbering
@@ -263,14 +260,14 @@ contains
   !! \since 2.0
   recursive subroutine kim_model_create_set_influence_distance_pointer( &
     model_create_handle, influence_distance)
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
       recursive subroutine set_influence_distance_pointer(model_create, &
-        influence_distance) &
+                                                          influence_distance) &
         bind(c, name="KIM_ModelCreate_SetInfluenceDistancePointer")
         use, intrinsic :: iso_c_binding
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(c_ptr), intent(in), value :: influence_distance
@@ -282,7 +279,7 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     call set_influence_distance_pointer(model_create, &
-      c_loc(influence_distance))
+                                        c_loc(influence_distance))
   end subroutine kim_model_create_set_influence_distance_pointer
 
   !> \brief \copybrief KIM::ModelCreate::SetNeighborListPointers
@@ -294,15 +291,15 @@ contains
   recursive subroutine kim_model_create_set_neighbor_list_pointers( &
     model_create_handle, number_of_neighbor_lists, cutoffs, &
     model_will_not_request_neighbors_of_noncontributing_particles)
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
-      recursive subroutine set_neighbor_list_pointers(model_create, &
-        number_of_neighbor_lists, cutoffs_ptr, &
+      recursive subroutine set_neighbor_list_pointers( &
+        model_create, number_of_neighbor_lists, cutoffs_ptr, &
         model_will_not_request_neighbors_of_noncontributing_particles) &
         bind(c, name="KIM_ModelCreate_SetNeighborListPointers")
         use, intrinsic :: iso_c_binding
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         integer(c_int), intent(in), value :: number_of_neighbor_lists
@@ -320,8 +317,8 @@ contains
     type(kim_model_create_type), pointer :: model_create
 
     call c_f_pointer(model_create_handle%p, model_create)
-    call set_neighbor_list_pointers(model_create, number_of_neighbor_lists, &
-      c_loc(cutoffs), &
+    call set_neighbor_list_pointers( &
+      model_create, number_of_neighbor_lists, c_loc(cutoffs), &
       c_loc(model_will_not_request_neighbors_of_noncontributing_particles))
   end subroutine kim_model_create_set_neighbor_list_pointers
 
@@ -333,18 +330,18 @@ contains
   recursive subroutine kim_model_create_set_routine_pointer( &
     model_create_handle, model_routine_name, language_name, required, fptr, &
     ierr)
-    use kim_model_routine_name_module, only : kim_model_routine_name_type
-    use kim_language_name_module, only : kim_language_name_type
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_model_routine_name_module, only: kim_model_routine_name_type
+    use kim_language_name_module, only: kim_language_name_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
-      integer(c_int) recursive function set_routine_pointer(model_create, &
-        model_routine_name, language_name, required, fptr) &
+      integer(c_int) recursive function set_routine_pointer( &
+        model_create, model_routine_name, language_name, required, fptr) &
         bind(c, name="KIM_ModelCreate_SetRoutinePointer")
         use, intrinsic :: iso_c_binding
-        use kim_model_routine_name_module, only : kim_model_routine_name_type
-        use kim_language_name_module, only : kim_language_name_type
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_model_routine_name_module, only: kim_model_routine_name_type
+        use kim_language_name_module, only: kim_language_name_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(kim_model_routine_name_type), intent(in), value &
@@ -364,7 +361,7 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     ierr = set_routine_pointer(model_create, model_routine_name, &
-      language_name, required, fptr)
+                               language_name, required, fptr)
   end subroutine kim_model_create_set_routine_pointer
 
   !> \brief \copybrief KIM::ModelCreate::SetSpeciesCode
@@ -372,18 +369,18 @@ contains
   !! \sa KIM::ModelCreate::SetSpeciesCode, KIM_ModelCreate_SetSpeciesCode
   !!
   !! \since 2.0
-  recursive subroutine kim_model_create_set_species_code(model_create_handle, &
-    species_name, code, ierr)
-    use kim_species_name_module, only : kim_species_name_type
-    use kim_interoperable_types_module, only : kim_model_create_type
+  recursive subroutine kim_model_create_set_species_code( &
+    model_create_handle, species_name, code, ierr)
+    use kim_species_name_module, only: kim_species_name_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
       integer(c_int) recursive function set_species_code(model_create, &
-        species_name, code) &
+                                                         species_name, code) &
         bind(c, name="KIM_ModelCreate_SetSpeciesCode")
         use, intrinsic :: iso_c_binding
-        use kim_species_name_module, only : kim_species_name_type
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_species_name_module, only: kim_species_name_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(kim_species_name_type), intent(in), value :: species_name
@@ -408,7 +405,7 @@ contains
   !! \since 2.0
   recursive subroutine kim_model_create_set_parameter_pointer_integer( &
     model_create_handle, int1, name, description, ierr)
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     type(kim_model_create_handle_type), intent(in) :: model_create_handle
     integer(c_int), intent(in), target :: int1(:)
@@ -419,20 +416,20 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     call set_parameter(model_create, size(int1, 1, c_int), int1, name, &
-      description, ierr)
+                       description, ierr)
     return
 
   contains
     recursive subroutine set_parameter(model_create, extent, int1, name, &
-      description, ierr)
-      use kim_interoperable_types_module, only : kim_model_create_type
+                                       description, ierr)
+      use kim_interoperable_types_module, only: kim_model_create_type
       implicit none
       interface
         integer(c_int) recursive function set_parameter_pointer_integer( &
           model_create, extent, ptr, name, description) &
           bind(c, name="KIM_ModelCreate_SetParameterPointerInteger")
           use, intrinsic :: iso_c_binding
-          use kim_interoperable_types_module, only : kim_model_create_type
+          use kim_interoperable_types_module, only: kim_model_create_type
           implicit none
           type(kim_model_create_type), intent(in) :: model_create
           integer(c_int), intent(in), value :: extent
@@ -448,9 +445,11 @@ contains
       character(len=*, kind=c_char), intent(in) :: description
       integer(c_int), intent(out) :: ierr
 
-      ierr = set_parameter_pointer_integer(model_create, extent, &
-        c_loc(int1), trim(name)//c_null_char, &
-        trim(description)//c_null_char)
+      ierr = set_parameter_pointer_integer(model_create, &
+                                           extent, &
+                                           c_loc(int1), &
+                                           trim(name)//c_null_char, &
+                                           trim(description)//c_null_char)
     end subroutine set_parameter
   end subroutine kim_model_create_set_parameter_pointer_integer
 
@@ -462,7 +461,7 @@ contains
   !! \since 2.0
   recursive subroutine kim_model_create_set_parameter_pointer_double( &
     model_create_handle, double1, name, description, ierr)
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     type(kim_model_create_handle_type), intent(in) :: model_create_handle
     real(c_double), intent(in), target :: double1(:)
@@ -473,19 +472,19 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     call set_parameter(model_create, size(double1, 1, c_int), double1, &
-      name, description, ierr)
+                       name, description, ierr)
     return
 
   contains
     recursive subroutine set_parameter(model_create, extent, double1, name, &
-      description, ierr)
+                                       description, ierr)
       implicit none
       interface
         integer(c_int) recursive function set_parameter_pointer_double( &
           model_create, extent, ptr, name, description) &
           bind(c, name="KIM_ModelCreate_SetParameterPointerDouble")
           use, intrinsic :: iso_c_binding
-          use kim_interoperable_types_module, only : kim_model_create_type
+          use kim_interoperable_types_module, only: kim_model_create_type
           implicit none
           type(kim_model_create_type), intent(in) :: model_create
           integer(c_int), intent(in), value :: extent
@@ -501,9 +500,11 @@ contains
       character(len=*, kind=c_char), intent(in) :: description
       integer(c_int), intent(out) :: ierr
 
-      ierr = set_parameter_pointer_double(model_create, extent, &
-        c_loc(double1), trim(name)//c_null_char, &
-        trim(description)//c_null_char)
+      ierr = set_parameter_pointer_double(model_create, &
+                                          extent, &
+                                          c_loc(double1), &
+                                          trim(name)//c_null_char, &
+                                          trim(description)//c_null_char)
     end subroutine set_parameter
   end subroutine kim_model_create_set_parameter_pointer_double
 
@@ -515,13 +516,13 @@ contains
   !! \since 2.0
   recursive subroutine kim_model_create_set_model_buffer_pointer( &
     model_create_handle, ptr)
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
       recursive subroutine set_model_buffer_pointer(model_create, ptr) &
         bind(c, name="KIM_ModelCreate_SetModelBufferPointer")
         use, intrinsic :: iso_c_binding
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(c_ptr), intent(in), value :: ptr
@@ -540,28 +541,28 @@ contains
   !! \sa KIM::ModelCreate::SetUnits, KIM_ModelCreate_SetUnits
   !!
   !! \since 2.0
-  recursive subroutine kim_model_create_set_units(model_create_handle, &
-    length_unit, energy_unit, charge_unit, temperature_unit, time_unit, ierr)
-    use kim_unit_system_module, only : &
+  recursive subroutine kim_model_create_set_units( &
+    model_create_handle, length_unit, energy_unit, charge_unit, &
+    temperature_unit, time_unit, ierr)
+    use kim_unit_system_module, only: &
       kim_length_unit_type, &
       kim_energy_unit_type, &
       kim_charge_unit_type, &
       kim_temperature_unit_type, &
       kim_time_unit_type
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
-      integer(c_int) recursive function set_units(model_create, length_unit, &
-        energy_unit, charge_unit, temperature_unit, time_unit) &
-        bind(c, name="KIM_ModelCreate_SetUnits")
+      integer(c_int) recursive function set_units( &
+        model_create, length_unit, energy_unit, charge_unit, temperature_unit, &
+        time_unit) bind(c, name="KIM_ModelCreate_SetUnits")
         use, intrinsic :: iso_c_binding
-        use kim_unit_system_module, only : &
-          kim_length_unit_type, &
-          kim_energy_unit_type, &
-          kim_charge_unit_type, &
-          kim_temperature_unit_type, &
-          kim_time_unit_type
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_unit_system_module, only: kim_length_unit_type, &
+                                          kim_energy_unit_type, &
+                                          kim_charge_unit_type, &
+                                          kim_temperature_unit_type, &
+                                          kim_time_unit_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(kim_length_unit_type), intent(in), value :: length_unit
@@ -582,7 +583,7 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     ierr = set_units(model_create, length_unit, energy_unit, &
-      charge_unit, temperature_unit, time_unit)
+                     charge_unit, temperature_unit, time_unit)
   end subroutine kim_model_create_set_units
 
   !> \brief \copybrief KIM::ModelCreate::ConvertUnit
@@ -596,11 +597,11 @@ contains
     to_length_unit, to_energy_unit, to_charge_unit, to_temperature_unit, &
     to_time_unit, length_exponent, energy_exponent, charge_exponent, &
     temperature_exponent, time_exponent, conversion_factor, ierr)
-    use kim_unit_system_module, only : kim_length_unit_type
-    use kim_unit_system_module, only : kim_energy_unit_type
-    use kim_unit_system_module, only : kim_charge_unit_type
-    use kim_unit_system_module, only : kim_temperature_unit_type
-    use kim_unit_system_module, only : kim_time_unit_type
+    use kim_unit_system_module, only: kim_length_unit_type
+    use kim_unit_system_module, only: kim_energy_unit_type
+    use kim_unit_system_module, only: kim_charge_unit_type
+    use kim_unit_system_module, only: kim_temperature_unit_type
+    use kim_unit_system_module, only: kim_time_unit_type
     implicit none
     interface
       integer(c_int) recursive function convert_unit( &
@@ -611,11 +612,11 @@ contains
         temperature_exponent, time_exponent, conversion_factor) &
         bind(c, name="KIM_ModelCreate_ConvertUnit")
         use, intrinsic :: iso_c_binding
-        use kim_unit_system_module, only : kim_length_unit_type
-        use kim_unit_system_module, only : kim_energy_unit_type
-        use kim_unit_system_module, only : kim_charge_unit_type
-        use kim_unit_system_module, only : kim_temperature_unit_type
-        use kim_unit_system_module, only : kim_time_unit_type
+        use kim_unit_system_module, only: kim_length_unit_type
+        use kim_unit_system_module, only: kim_energy_unit_type
+        use kim_unit_system_module, only: kim_charge_unit_type
+        use kim_unit_system_module, only: kim_temperature_unit_type
+        use kim_unit_system_module, only: kim_time_unit_type
         implicit none
         type(kim_length_unit_type), intent(in), value :: from_length_unit
         type(kim_energy_unit_type), intent(in), value :: from_energy_unit
@@ -655,11 +656,12 @@ contains
     real(c_double), intent(out) :: conversion_factor
     integer(c_int), intent(out) :: ierr
 
-    ierr = convert_unit(from_length_unit, &
-      from_energy_unit, from_charge_unit, from_temperature_unit, &
-      from_time_unit, to_length_unit, to_energy_unit, to_charge_unit, &
-      to_temperature_unit, to_time_unit, length_exponent, energy_exponent, &
-      charge_exponent, temperature_exponent, time_exponent, conversion_factor)
+    ierr = convert_unit(from_length_unit, from_energy_unit, from_charge_unit, &
+                        from_temperature_unit, from_time_unit, to_length_unit, &
+                        to_energy_unit, to_charge_unit, to_temperature_unit, &
+                        to_time_unit, length_exponent, energy_exponent, &
+                        charge_exponent, temperature_exponent, time_exponent, &
+                        conversion_factor)
   end subroutine kim_model_create_convert_unit
 
   !> \brief \copybrief KIM::ModelCreate::LogEntry
@@ -668,16 +670,17 @@ contains
   !!
   !! \since 2.0
   recursive subroutine kim_model_create_log_entry(model_create_handle, &
-    log_verbosity, message)
-    use kim_log_verbosity_module, only : kim_log_verbosity_type
-    use kim_interoperable_types_module, only : kim_model_create_type
+                                                  log_verbosity, message)
+    use kim_log_verbosity_module, only: kim_log_verbosity_type
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
       recursive subroutine log_entry(model_create, log_verbosity, message, &
-        line_number, file_name) bind(c, name="KIM_ModelCreate_LogEntry")
+                                     line_number, file_name) &
+        bind(c, name="KIM_ModelCreate_LogEntry")
         use, intrinsic :: iso_c_binding
-        use kim_log_verbosity_module, only : kim_log_verbosity_type
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_log_verbosity_module, only: kim_log_verbosity_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
         type(kim_log_verbosity_type), intent(in), value :: log_verbosity
@@ -693,7 +696,7 @@ contains
 
     call c_f_pointer(model_create_handle%p, model_create)
     call log_entry(model_create, log_verbosity, trim(message)//c_null_char, &
-      0, ""//c_null_char)
+                   0, ""//c_null_char)
   end subroutine kim_model_create_log_entry
 
   !> \brief \copybrief KIM::ModelCreate::ToString
@@ -702,14 +705,14 @@ contains
   !!
   !! \since 2.0
   recursive subroutine kim_model_create_to_string(model_create_handle, string)
-    use kim_convert_string_module, only : kim_convert_c_char_ptr_to_string
-    use kim_interoperable_types_module, only : kim_model_create_type
+    use kim_convert_string_module, only: kim_convert_c_char_ptr_to_string
+    use kim_interoperable_types_module, only: kim_model_create_type
     implicit none
     interface
       type(c_ptr) recursive function model_create_string(model_create) &
         bind(c, name="KIM_ModelCreate_ToString")
         use, intrinsic :: iso_c_binding
-        use kim_interoperable_types_module, only : kim_model_create_type
+        use kim_interoperable_types_module, only: kim_model_create_type
         implicit none
         type(kim_model_create_type), intent(in) :: model_create
       end function model_create_string
